@@ -1,6 +1,6 @@
 package Parse::Dia::SQL::Const;
 
-# $Id: Const.pm,v 1.8 2009/04/01 07:31:10 aff Exp $
+# $Id: Const.pm,v 1.1 2009/02/23 07:36:17 aff Exp $
 
 =pod
 
@@ -11,8 +11,8 @@ Parse::Dia::SQL::Const - Constants and lookup methods
 =head1 SYNOPSIS
 
     use Parse::Dia::SQL::Const;
-    my $const = Parse::Dia::SQL::Const->new();
-    my @rdbms = $const->get_rdbms();
+    my $const = Parse::Dia::SQL::Const::->new();
+    my @list = $const->get_small_pack_gen_seq()
 
 =head1 DESCRIPTION
 
@@ -30,23 +30,20 @@ use Parse::Dia::SQL::Logger;
 # List of supported relational database management systems
 my @RDBMS = qw (
   db2
-  html
   informix
   ingres
   innodb
   mssql
-  mysql-innodb
   mysql-myisam
+  mysql-innodb
   oracle
   postgres
   sas
-  sqlite3
   sybase
 );
 
 my %OUTPUT_CLASS = (
   'db2'          => 'Parse::Dia::SQL::Output::DB2',
-  'html'         => 'Parse::Dia::SQL::Output::HTML',
   'informix'     => 'Parse::Dia::SQL::Output::Informix',
   'ingres'       => 'Parse::Dia::SQL::Output::Ingres',
   'innodb'       => 'Parse::Dia::SQL::Output::InnoDB',
@@ -56,7 +53,6 @@ my %OUTPUT_CLASS = (
   'oracle'       => 'Parse::Dia::SQL::Output::Oracle',
   'postgres'     => 'Parse::Dia::SQL::Output::Postgres',
   'sas'          => 'Parse::Dia::SQL::Output::SAS',
-  'sqlite3'      => 'Parse::Dia::SQL::Output::SQLite3',
   'sybase'       => 'Parse::Dia::SQL::Output::Sybase',
 );
 
@@ -90,7 +86,7 @@ sub new {
 
 =head2 get_rdbms
 
-Return list of supported databases.
+Return list of databases.
 
 =cut
 
@@ -120,9 +116,9 @@ Database to class lookup. Used by Output->new.
 sub get_class_name {
   my ($self, $db) = @_;
   if (exists($OUTPUT_CLASS{$db})) {
-		return $OUTPUT_CLASS{$db};
+	return $OUTPUT_CLASS{$db};
   } else {
-		return;
+	return;
   }
 }
 
