@@ -1,6 +1,6 @@
 package Parse::Dia::SQL::Logger;
 
-# $Id: Logger.pm,v 1.8 2010/04/15 20:41:00 aff Exp $
+# $Id: Logger.pm,v 1.1 2009/02/23 07:36:17 aff Exp $
 
 =pod
 
@@ -22,7 +22,7 @@ This module is a wrapper around Log::Log4perl.
 
 =head1 SEE ALSO
 
-  Log::Log4perl
+  Log::Logperl
 
 Make appender_thresholds_adjust return number of appenders changed:
 
@@ -34,9 +34,7 @@ use warnings;
 use strict;
 
 use Log::Log4perl;
-
-use constant APPENDER_THRESHOLDS_ADJUST_LOGOFF =>  7;
-use constant APPENDER_THRESHOLDS_ADJUST_LOGON  => -7;
+use Log::Dispatch::FileRotate;
 
 =head2 new
 
@@ -57,20 +55,37 @@ sub new {
   return $self;
 }
 
-# Initialize the logger.  The commented lines are deliberately left to
-# serve as exmples.
+=head2 _init_log
+
+Initialize the logger.  The commented lines are deliberately left to
+serve as exmples.
+
+=cut 
+
 sub _init_log {
   my $self = shift;
 
   # Init logging
   my $conf = q(
     # Main logger for Parse::Dia::SQL
+#    log4perl.category.Parse::Dia::SQL        = INFO, file, screen-main
+#    log4perl.category.Parse::Dia::SQL        = DEBUG, file, screen-main
+#    log4perl.category.Parse::Dia::SQL        = WARN, screen-main
 #    log4perl.category.Parse::Dia::SQL        = DEBUG, screen-main
     log4perl.category.Parse::Dia::SQL        = INFO, screen-main
     log4perl.appender.screen-main         = Log::Log4perl::Appender::Screen
-    log4perl.appender.screen-main.stderr  = 0
+    log4perl.appender.screen-main.stderr  = 1
     log4perl.appender.screen-main.layout  = PatternLayout
-    log4perl.appender.screen-main.layout.ConversionPattern=[%p] %m%n 
+    log4perl.appender.screen-main.layout.ConversionPattern=[%p] %F %L %M %m%n 
+
+    log4perl.appender.file           = Log::Dispatch::FileRotate
+    log4perl.appender.file.filename  = dia-sql.log
+    log4perl.appender.file.mode      = append
+    log4perl.appender.file.size      = 100000
+    log4perl.appender.file.max       = 5
+    log4perl.appender.file.layout    = PatternLayout
+    log4perl.appender.file.layout.ConversionPattern=[%p] %d %F:%L: %m%n
+
 
     # Separate logger for Output::*
 #    log4perl.category.Parse::Dia::SQL::Output  = DEBUG, screen-output
@@ -78,7 +93,7 @@ sub _init_log {
     log4perl.appender.screen-output            = Log::Log4perl::Appender::Screen
     log4perl.appender.screen-output.stderr     = 1
     log4perl.appender.screen-output.layout     = PatternLayout
-    log4perl.appender.screen-output.layout.ConversionPattern=[%p] %m%n 
+    log4perl.appender.screen-output.layout.ConversionPattern=[%p] %F %L %M %m%n 
     log4perl.additivity.Parse::Dia::SQL::Output  = 0
 
     # Separate logger for Utils.pm
@@ -87,16 +102,12 @@ sub _init_log {
     log4perl.appender.screen-utils            = Log::Log4perl::Appender::Screen
     log4perl.appender.screen-utils.stderr     = 1
     log4perl.appender.screen-utils.layout     = PatternLayout
-    log4perl.appender.screen-utils.layout.ConversionPattern=[%p] %m%n 
+    log4perl.appender.screen-utils.layout.ConversionPattern=[%p] %F %L %M %m%n 
     log4perl.additivity.Parse::Dia::SQL::Utils  = 0
 
   );
   
   Log::Log4perl::init( \$conf );
-
-  # Adjust call stack for caller class, see man Log::Log4perl
-  $Log::Log4perl::caller_depth = 1;
-    
   return 1;
 }
 
@@ -122,11 +133,9 @@ Decrease log level on all appenders.
 sub log_off {
   my $self = shift;
 
-  # Make sure it works also in case this is
-  # called as function before object is blessed.
-  _init_log() if ( !Log::Log4perl->initialized() );
+  $self->_init_log() unless Log::Log4perl->initialized();
 
-  Log::Log4perl->appender_thresholds_adjust(APPENDER_THRESHOLDS_ADJUST_LOGOFF);
+  Log::Log4perl->appender_thresholds_adjust(7);
 
   return 1;
 }
@@ -140,11 +149,9 @@ Increase log level on all appenders.
 sub log_on {
   my $self = shift;
 
-  # Make sure it works also in case this is
-  # called as function before object is blessed.
-  _init_log() if ( !Log::Log4perl->initialized() );
+  $self->_init_log() unless Log::Log4perl->initialized();
 
-  Log::Log4perl->appender_thresholds_adjust(APPENDER_THRESHOLDS_ADJUST_LOGON);
+  Log::Log4perl->appender_thresholds_adjust(-7);
 
   return 1;
 }
