@@ -1,22 +1,6 @@
 package Parse::Dia::SQL::Utils;
 
-# $Id: Utils.pm,v 1.13 2011/02/16 10:23:11 aff Exp $
-
-=pod
-
-=head1 NAME
-
-Parse::Dia::SQL::Utils - Helper class for Parse::Dia::SQL.
-
-=head1 SYNOPSIS
-
-  Not to be used directly.
-
-=head1 DESCRIPTION
-
-Utility functions for Parse::Dia::SQL.
-
-=cut
+# $Id: Utils.pm,v 1.1 2009/02/23 07:36:17 aff Exp $
 
 use warnings;
 use strict;
@@ -32,13 +16,11 @@ use Parse::Dia::SQL::Logger;
 my %MAX_NAME_LEN = (
   default  => 30,
   db2      => 18,
-  html     => 64,
   innodb   => 64,
   mysql    => 64,
   oracle   => 30,
   postgres => 63,
   sas      => 32,
-  sqlite3  => 60,
 );
 
 # TODO: Make this a object variable
@@ -90,13 +72,12 @@ sub new {
     log        => undef,
     db         => $param{db} || undef,
     default_pk => $param{default_pk} || undef,
-    loglevel   => $param{loglevel} || undef,
   };
 
   bless($self, $class);
 
   # init logger
-  my $logger = Parse::Dia::SQL::Logger::->new(loglevel => $self->{loglevel});
+  my $logger = Parse::Dia::SQL::Logger::->new();
   $self->{log} = $logger->get_logger(__PACKAGE__);
 
   return $self;
@@ -128,9 +109,14 @@ sub get_node_attribute_values {
   my ( $currentNode, $nodeAttrName, $i );
   my %return;
 
-  my $emptyValueString  = "__undef_string__";
-  my $emptyValueNumber  = "__undef_numeric__";
-  my $emptyValueBoolean = "__undef_boolean__";
+ # drTAE: hopefully Dia will never use this string as an actual value in its XML
+ # document save format, 'cuz I'm using it as a special "undef/NULL" construct
+  my $emptyValueString =
+"__this_is_a_very_very_empty_STRING_value_that_i_hope_no-one_will_ever_use (it's like NULL or 'undef')__";
+  my $emptyValueNumber =
+"__this_is_a_very_very_empty_NUMERIC_value_that_i_hope_no-one_will_ever_use (it's like NULL or 'undef')__";
+  my $emptyValueBoolean =
+"__this_is_a_very_very_empty_BOOLEAN_value_that_i_hope_no-one_will_ever_use (it's like NULL or 'undef')__";
 
   # initialise it to a bunch of empty values, this will also allow
   # us to know which attribute name values to parse out of the
@@ -170,11 +156,6 @@ sub get_node_attribute_values {
     }
   }
 
-	{
-		no warnings q{uninitialized};
-		$self->{log}->debug( "$nodeAttrName:" . $return{$nodeAttrName} );
-	} 
-
   # don't return some fake value for bits we didn't parse,
   # return undef which means it wasn't there
   foreach my $singleInfo (@infosToGet) {
@@ -217,8 +198,6 @@ sub get_string_from_node {
     }
   }
 
-	return if !$retval; # Skip escaping if empty
-
   #	$retval =~ s/^#?(.*)#?$/$1/g;
   $retval =~ s/^#//;
   $retval =~ s/#$//;
@@ -327,9 +306,11 @@ sub name_case {
   return lc($value);    # Assumes that all other DBMSs ignore case of names!
 }
 
+# if it looks like <thingy><dia:enum val="value"></thingy> then we
+# will get the 'value' part out given the node is 'thingy'
+
 =head2 get_num_from_node
 
-Return value part of <dia:enum val="value"></thingy>.
 
 =cut
 
@@ -339,9 +320,11 @@ sub get_num_from_node {
 	return $enumNode->getAttribute('val');
 }
 
+# if it looks like <thingy><dia:boolean val="value"></thingy> then we
+# will get the 'value' part out given the node is 'thingy'
+
 =head2 get_bool_from_node
 
-Return value part of <thingy><dia:boolean val="value"></thingy>.
 
 =cut
 
@@ -351,19 +334,18 @@ sub get_bool_from_node {
 	return $enumNode->getAttribute('val');
 }
 
+# Look at a multiplicity descriptor and classify it as 'one' (1, or 1..1),
+# 'zone' (0..1), 'many' (n..m, n..*, where n > 1, m >= n) and 'zmany'
+# (0..n, 0..*, where n > 1)
 
 =head2 classify_multiplicity
 
-Look at a multiplicity descriptor and classify it as 'one' (1, or
-1..1), 'zone' (0..1), 'many' (n..m, n..*, where n > 1, m >= n) and
-'zmany' (0..n, 0..*, where n > 1)
 
 =cut
 
 sub classify_multiplicity {
   my $self    = shift;
   my $multStr = shift;
-  return 'none'  if ( ! $multStr );
   $multStr =~ s/\s//g;
   my @mult = split( /\.\./, $multStr );
   return 'none'  if ( @mult == 0 );
@@ -386,13 +368,13 @@ sub classify_multiplicity {
 }
 
 
-# =head2 parseExtras
+=head2 parseExtras
 
-# Parse the name of a Small Package that contains extra SQL clauses for
-# the generated SQL, and add the SmallPackage text to the appropriate
-# %tableExtras table for the type of extra clause (table, pk, index).
+Parse the name of a Small Package that contains extra SQL clauses for
+the generated SQL, and add the SmallPackage text to the appropriate
+%tableExtras table for the type of extra clause (table, pk, index).
 
-# =cut
+=cut
 
 # sub parseExtras {
 #   my $self   = shift;
@@ -518,6 +500,7 @@ sub check_att_list_types {
     }
   }
 
+  # if $opt_M is set, then $mismatches == 0 anyway
   return $mismatches == 0;
 }
 
@@ -527,9 +510,7 @@ Check that a list of primary key attributes has types corresponding to
 the types in a list of foreign key attributes.
 
 Returns base type of some DMBS specific types (eg in PostgreSQL serial
-is integer).
-
-AFF note:  This is better implemented in each sql formatter class.
+is int).
 
 =cut
 
@@ -540,19 +521,9 @@ sub get_base_type {
   if ( $db eq 'postgres' ) {
 
     # handle PostgreSQL database type
-    if ( lc($typeName) eq 'serial' or lc($typeName) eq 'int4' or lc($typeName) eq 'int') {
-			$self->{log}->info(qq{Replaced $typeName with integer}) if $self->{log}->is_info();
-      return 'integer';
+    if ( $typeName eq 'serial' || $typeName eq 'SERIAL' ) {
+      return 'int';
     }
-    if ( lc($typeName) eq 'int2' ) {
-			$self->{log}->info(qq{Replaced $typeName with smallint}) if $self->{log}->is_info();
-      return 'smallint';
-    }
-    if ( lc($typeName) eq 'int8' ) {
-			$self->{log}->info(qq{Replaced $typeName with bigint}) if $self->{log}->is_info();
-      return 'bigint';
-    }
-
     return $typeName;
   }
   elsif ( $db eq 'templateDBMStype' ) {
@@ -858,65 +829,6 @@ sub add_default_fk {
 }
 
 
-# Check that the given object and version is supported.  Return true
-# on pass, undef on fail.
-sub _check_object_version {
-  my $self    = shift;
-  my $type    = shift;
-  my $version = int shift;    # can be zero, can have leading zeros
-  
-  if (!$type || !defined $version) {
-    $self->{log}->error(qq{Need 2 args: type and version});
-    return;
-  }
-
-  my %object_v = (
-                  "UML - Association"  => [1,2],
-                  "UML - Class"        => [0],
-                  "UML - Component"    => [0],
-                  "UML - Note"         => [0],
-                  "UML - SmallPackage" => [0],
-                 );
-
-  $self->{log}->debug(qq{type:'$type' version:$version});
-
-  if (!exists($object_v{$type})) {
-    $self->{log}->debug(qq{type:'$type' unknown});
-    return;
-  }
-
-  if (! grep(/^$version$/, @{$object_v{$type}})) {
-    $self->{log}->debug(qq{type:'$type' version:$version unsupported});
-    return;
-  }
-
-  return 1;
-}
-
-# Split a type definition 'type(nn)' into 'type', '(nn)'
-sub split_type {
-	my $self = shift;
-	my $type = shift;
-
-	if(!$type) {
-		$self->{log}->warn("Missing type");
-		return;
-	}
-
-	$type =~ m/^([^(]*)(\([^)]+\))?$/;
-	my ($name, $size) = ($1, $2);
-	if(!$name) {
-		$self->{log}->warn("Malformed type name $type");
-		return;
-	}
-
-	if ($size) {
-		return ($name,$size);
-	} else {
-		return ($name);
-	}
-}
-
 # =head2 parseExtras
 
 # Parse the name of a Small Package that contains extra SQL clauses for
@@ -978,4 +890,18 @@ sub split_type {
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Parse::Dia::SQL::Utils - Helper class for Parse::Dia::SQL.
+
+=head1 SYNOPSIS
+
+  Not to be used directly.
+
+=head1 DESCRIPTION
+
+Utility functions for Parse::Dia::SQL.
+
 # End of Parse::Dia::SQL::Utils
